==> blob-common-1.4.2.tgz: package/core/handler.js <==
export const handler = (lambda) => {
    return function (event, context) {
        return Promise.resolve()
            // Run the Lambda
            .then(() => lambda(event, context))
            // On success
            .then((responseBody) => [200, responseBody])
            // On failure
            .catch((e) => {
                console.log(e);
                return [500, { error: e.message }];
            })
            // Return HTTP response
            .then(([statusCode, body]) => ({
                statusCode,
                headers: {
                    "Access-Control-Allow-Origin": "*",
                    "Access-Control-Allow-Credentials": true,
                },
                body: JSON.stringify(body),
            }));
    };
}

export const getUserFromEvent = (event) => {
    const authProvider = event.requestContext?.identity?.cognitoAuthenticationProvider;
    // if unAuth visit return empty
    if (!authProvider) return null;

    // Cognito authentication provider looks like:
    // cognito-idp.us-east-1.amazonaws.com/us-east-1_xxxxxxxxx,cognito-idp.us-east-1.amazonaws.com/us-east-1_aaaaaaaaa:CognitoSignIn:qqqqqqqq-1111-2222-3333-rrrrrrrrrrrr
    // Where us-east-1_aaaaaaaaa is the User Pool id
    // And qqqqqqqq-1111-2222-3333-rrrrrrrrrrrr is the User Pool User Id
    const parts = authProvider.split(':');

    // const userPoolIdParts = parts[parts.length - 3].split('/');
    // const userPoolId = userPoolIdParts[userPoolIdParts.length - 1];
    const userPoolUserId = parts[parts.length - 1];

    return 'U' + userPoolUserId;
};

export const apiCall = async (promise) => {
    try {
        return [null, await promise]
    } catch (error) {
        return [error, null]
    }
}

==> blob-common-1.4.4.tgz: package/core/handler.js <==
export const handler = (lambda) => {
    return function (event, context) {
        return Promise.resolve()
            // Run the Lambda
            .then(() => lambda(event, context))
            // On success
            .then((responseBody) => [200, responseBody])
            // On failure
            .catch((e) => {
                console.log(e);
                return [500, { error: e.message }];
            })
            // Return HTTP response
            .then(([statusCode, body]) => ({
                statusCode,
                headers: {
                    "Access-Control-Allow-Origin": "*",
                    "Access-Control-Allow-Credentials": true,
                },
                body: JSON.stringify(body),
            }));
    };
}

export const getUserFromEvent = (event) => {
    const baseAuthProvider = event.requestContext.identity?.cognitoAuthenticationProvider;
    // works differently for calls from node, maybe because http API works differently with sigv4Client
    const altApiIdentityAmr = event.requestContext.authorizer?.iam?.cognitoIdentity?.amr;
    const altAuthProvider = (altApiIdentityAmr && altApiIdentityAmr.length === 3 && altApiIdentityAmr[2]);

    const authProvider = baseAuthProvider || altAuthProvider;

    // if unAuth visit return empty
    if (!authProvider) return null;

    // Cognito authentication provider looks like:
    // cognito-idp.us-east-1.amazonaws.com/us-east-1_xxxxxxxxx,cognito-idp.us-east-1.amazonaws.com/us-east-1_aaaaaaaaa:CognitoSignIn:qqqqqqqq-1111-2222-3333-rrrrrrrrrrrr
    // Where us-east-1_aaaaaaaaa is the User Pool id
    // And qqqqqqqq-1111-2222-3333-rrrrrrrrrrrr is the User Pool User Id
    const parts = authProvider.split(':');

    // const userPoolIdParts = parts[parts.length - 3].split('/');
    // const userPoolId = userPoolIdParts[userPoolIdParts.length - 1];
    const userPoolUserId = parts[parts.length - 1];

    return 'U' + userPoolUserId;
};

export const apiCall = async (promise) => {
    try {
        return [null, await promise]
    } catch (error) {
        return [error, null]
    }
}
